@@ -13,6 +13,7 @@ import (
 	"github.com/hashicorp/vault/sdk/helper/automatedrotationutil"
 	"github.com/hashicorp/vault/sdk/helper/pluginidentityutil"
 	"github.com/hashicorp/vault/sdk/helper/pluginutil"
+	"github.com/hashicorp/vault/sdk/helper/testhelpers/observations"
 	"github.com/hashicorp/vault/sdk/logical"
 	"github.com/hashicorp/vault/sdk/rotation"
 	"github.com/stretchr/testify/assert"
@@ -23,7 +24,8 @@ func TestBackend_PathConfigRoot(t *testing.T) {
 	config := logical.TestBackendConfig()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
-
+	or := observations.NewTestObservationRecorder()
+	config.ObservationRecorder = or
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
 		t.Fatal(err)
@@ -60,6 +62,7 @@ func TestBackend_PathConfigRoot(t *testing.T) {
 		t.Fatalf("bad: config writing failed: resp:%#v\n err: %v", resp, err)
 	}
 
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 	resp, err = b.HandleRequest(context.Background(), &logical.Request{
 		Operation: logical.ReadOperation,
 		Storage:   config.StorageView,
@@ -68,6 +71,7 @@ func TestBackend_PathConfigRoot(t *testing.T) {
 	if err != nil || (resp != nil && resp.IsError()) {
 		t.Fatalf("bad: config reading failed: resp:%#v\n err: %v", resp, err)
 	}
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigRead))
 
 	// Ensure default values are enforced
 	configData["max_retries"] = -1
@@ -111,6 +115,7 @@ func TestBackend_PathConfigRoot(t *testing.T) {
 	if err != nil || (resp != nil && resp.IsError()) {
 		t.Fatalf("bad: config writing failed: resp:%#v\n err: %v", resp, err)
 	}
+	require.Equal(t, 2, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 
 	resp, err = b.HandleRequest(context.Background(), &logical.Request{
 		Operation: logical.ReadOperation,
@@ -120,6 +125,7 @@ func TestBackend_PathConfigRoot(t *testing.T) {
 	if err != nil || (resp != nil && resp.IsError()) {
 		t.Fatalf("bad: config reading failed: resp:%#v\n err: %v", resp, err)
 	}
+	require.Equal(t, 2, or.NumObservationsByType(ObservationTypeAWSRootConfigRead))
 
 	delete(configData, "secret_key")
 	require.Equal(t, configData, resp.Data)
@@ -131,8 +137,10 @@ func TestBackend_PathConfigRoot(t *testing.T) {
 // TestBackend_PathConfigRoot_STSFallback tests valid versions of STS fallback parameters - slice and csv
 func TestBackend_PathConfigRoot_STSFallback(t *testing.T) {
 	config := logical.TestBackendConfig()
+	or := observations.NewTestObservationRecorder()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	config.ObservationRecorder = or
 
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
@@ -170,6 +178,7 @@ func TestBackend_PathConfigRoot_STSFallback(t *testing.T) {
 		t.Fatalf("bad: config writing failed: resp:%#v\n err: %v", resp, err)
 	}
 
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 	resp, err = b.HandleRequest(context.Background(), &logical.Request{
 		Operation: logical.ReadOperation,
 		Storage:   config.StorageView,
@@ -178,6 +187,7 @@ func TestBackend_PathConfigRoot_STSFallback(t *testing.T) {
 	if err != nil || (resp != nil && resp.IsError()) {
 		t.Fatalf("bad: config reading failed: resp:%#v\n err: %v", resp, err)
 	}
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigRead))
 
 	delete(configData, "secret_key")
 	// remove rotation_period from response for comparison with original config
@@ -219,6 +229,7 @@ func TestBackend_PathConfigRoot_STSFallback(t *testing.T) {
 		t.Fatalf("bad: config writing failed: resp:%#v\n err: %v", resp, err)
 	}
 
+	require.Equal(t, 2, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 	resp, err = b.HandleRequest(context.Background(), &logical.Request{
 		Operation: logical.ReadOperation,
 		Storage:   config.StorageView,
@@ -228,6 +239,8 @@ func TestBackend_PathConfigRoot_STSFallback(t *testing.T) {
 		t.Fatalf("bad: config reading failed: resp:%#v\n err: %v", resp, err)
 	}
 
+	require.Equal(t, 2, or.NumObservationsByType(ObservationTypeAWSRootConfigRead))
+
 	delete(configData, "secret_key")
 	// remove rotation_period from response for comparison with original config
 	delete(resp.Data, "rotation_period")
@@ -240,18 +253,20 @@ func TestBackend_PathConfigRoot_STSFallback(t *testing.T) {
 }
 
 // TestBackend_PathConfigRoot_STSFallback_mismatchedfallback ensures configuration writing will fail if the
-// region/endpoint entries are different lengths
+// sts fallback regions and sts fallback endpoints entries are different lengths
 func TestBackend_PathConfigRoot_STSFallback_mismatchedfallback(t *testing.T) {
 	config := logical.TestBackendConfig()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	or := observations.NewTestObservationRecorder()
+	config.ObservationRecorder = or
 
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
 		t.Fatal(err)
 	}
 
-	// test we can handle comma separated strings, per CommaStringSlice
+	// sts fallback endpoints has 2 entries, regions has 1
 	configData := map[string]interface{}{
 		"access_key":              "AKIAEXAMPLE",
 		"secret_key":              "RandomData",
@@ -260,7 +275,7 @@ func TestBackend_PathConfigRoot_STSFallback_mismatchedfallback(t *testing.T) {
 		"sts_endpoint":            "https://sts.us-west-2.amazonaws.com",
 		"sts_region":              "",
 		"sts_fallback_endpoints":  "1.1.1.1,8.8.8.8",
-		"sts_fallback_regions":    "zone-1,zone-2",
+		"sts_fallback_regions":    "zone-1",
 		"max_retries":             10,
 		"username_template":       defaultUserNameTemplate,
 		"role_arn":                "",
@@ -279,9 +294,9 @@ func TestBackend_PathConfigRoot_STSFallback_mismatchedfallback(t *testing.T) {
 	if err != nil {
 		t.Fatalf("bad: config writing failed: err: %v", err)
 	}
-	if resp != nil && !resp.IsError() {
-		t.Fatalf("expected an error, but it successfully wrote")
-	}
+	require.NotNil(t, resp)
+	require.True(t, resp.IsError())
+	require.Equal(t, 0, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 }
 
 // TestBackend_PathConfigRoot_STSFallback_defaultEndpointRegion ensures that if no endpoints are specified, we can
@@ -290,6 +305,8 @@ func TestBackend_PathConfigRoot_STSFallback_defaultEndpointRegion(t *testing.T)
 	config := logical.TestBackendConfig()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	or := observations.NewTestObservationRecorder()
+	config.ObservationRecorder = or
 
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
@@ -330,6 +347,7 @@ func TestBackend_PathConfigRoot_STSFallback_defaultEndpointRegion(t *testing.T)
 			t.Fatalf("region and endpoint didn't match: %s vs. %s", *(cfg.Region), *(cfg.Endpoint))
 		}
 	}
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 }
 
 // TestBackend_PathConfigRoot_IAM_specifiedRegion ensures that if a region is set, we get a good config (with a blank
@@ -338,6 +356,8 @@ func TestBackend_PathConfigRoot_IAM_specifiedRegion(t *testing.T) {
 	config := logical.TestBackendConfig()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	or := observations.NewTestObservationRecorder()
+	config.ObservationRecorder = or
 
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
@@ -369,6 +389,7 @@ func TestBackend_PathConfigRoot_IAM_specifiedRegion(t *testing.T) {
 		t.Fatalf("bad: config writing failed: err: %v", err)
 	}
 
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 	cfg, err := b.getRootIAMConfig(context.Background(), config.StorageView, b.Logger())
 	if err != nil {
 		t.Fatalf("couldn't get IAM configs with default region/endpoints: %v", err)
@@ -385,8 +406,10 @@ func TestBackend_PathConfigRoot_IAM_specifiedRegion(t *testing.T) {
 // good config
 func TestBackend_PathConfigRoot_IAM_specifiedRegionAndEndpoint(t *testing.T) {
 	config := logical.TestBackendConfig()
+	or := observations.NewTestObservationRecorder()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	config.ObservationRecorder = or
 
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
@@ -420,6 +443,7 @@ func TestBackend_PathConfigRoot_IAM_specifiedRegionAndEndpoint(t *testing.T) {
 		t.Fatalf("bad: config writing failed: err: %v", err)
 	}
 
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 	cfg, err := b.getRootIAMConfig(context.Background(), config.StorageView, b.Logger())
 	if err != nil {
 		t.Fatalf("couldn't get IAM configs with default region/endpoints: %v", err)
@@ -439,6 +463,8 @@ func TestBackend_PathConfigRoot_IAM_defaultEndpointRegion(t *testing.T) {
 	config := logical.TestBackendConfig()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	or := observations.NewTestObservationRecorder()
+	config.ObservationRecorder = or
 
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
@@ -467,6 +493,7 @@ func TestBackend_PathConfigRoot_IAM_defaultEndpointRegion(t *testing.T) {
 		t.Fatalf("bad: config writing failed: err: %v", err)
 	}
 
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 	cfg, err := b.getRootIAMConfig(context.Background(), config.StorageView, b.Logger())
 	if err != nil {
 		t.Fatalf("couldn't get IAM configs with default region/endpoints: %v", err)
@@ -483,6 +510,8 @@ func TestBackend_PathConfigRoot_STSIAM_SetEverything(t *testing.T) {
 	config := logical.TestBackendConfig()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	or := observations.NewTestObservationRecorder()
+	config.ObservationRecorder = or
 
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
@@ -520,6 +549,7 @@ func TestBackend_PathConfigRoot_STSIAM_SetEverything(t *testing.T) {
 		t.Fatalf("bad: config writing failed: err: %v", err)
 	}
 
+	require.Equal(t, 1, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 	// get IAM
 	cfg, err := b.getRootIAMConfig(context.Background(), config.StorageView, b.Logger())
 	if err != nil {
@@ -549,6 +579,8 @@ func TestBackend_PathConfigRoot_PluginIdentityToken(t *testing.T) {
 	config := logical.TestBackendConfig()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	or := observations.NewTestObservationRecorder()
+	config.ObservationRecorder = or
 
 	b := Backend(config)
 	if err := b.Setup(context.Background(), config); err != nil {
@@ -572,6 +604,7 @@ func TestBackend_PathConfigRoot_PluginIdentityToken(t *testing.T) {
 	assert.NoError(t, err)
 	assert.NotNil(t, resp)
 	assert.ErrorContains(t, resp.Error(), pluginidentityutil.ErrPluginWorkloadIdentityUnsupported.Error())
+	require.Equal(t, 0, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 }
 
 // TestBackend_PathConfigRoot_RegisterRootRotation tests that configuration
@@ -580,6 +613,8 @@ func TestBackend_PathConfigRoot_RegisterRootRotation(t *testing.T) {
 	config := logical.TestBackendConfig()
 	config.StorageView = &logical.InmemStorage{}
 	config.System = &testSystemView{}
+	or := observations.NewTestObservationRecorder()
+	config.ObservationRecorder = or
 
 	nsCtx := namespace.ContextWithNamespace(context.Background(), namespace.RootNamespace)
 
@@ -606,6 +641,7 @@ func TestBackend_PathConfigRoot_RegisterRootRotation(t *testing.T) {
 	assert.NoError(t, err)
 	assert.NotNil(t, resp)
 	assert.ErrorContains(t, resp.Error(), automatedrotationutil.ErrRotationManagerUnsupported.Error())
+	require.Equal(t, 0, or.NumObservationsByType(ObservationTypeAWSRootConfigWrite))
 }
 
 type testSystemView struct {
