@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2016, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package http
@@ -7,6 +7,7 @@ import (
 	"bytes"
 	"context"
 	"encoding/json"
+	"fmt"
 	"io"
 	"io/ioutil"
 	"net/http"
@@ -283,12 +284,24 @@ func TestLogical_RequestSizeLimit(t *testing.T) {
 	defer ln.Close()
 	TestServerAuth(t, addr, token)
 
-	// Write a very large object, should fail. This test works because Go will
-	// convert the byte slice to base64, which makes it significantly larger
-	// than the default max request size.
-	resp := testHttpPut(t, token, addr+"/v1/secret/foo", map[string]interface{}{
-		"data": make([]byte, DefaultMaxRequestSize),
-	})
+	// To test the server's max request size limit (which returns 413),
+	// we must create a payload that is larger than the limit in total, but
+	// does not violate any of the JSON parser's individual limits (like max
+	// string length), which would return a 500 error first.
+	//
+	// We do this by creating many key-value pairs, where each value is a
+	// moderately sized string.
+	const valueSize = 4096 // 4KB, well under the 1MB string limit
+	numEntries := (DefaultMaxRequestSize / valueSize) + 1
+	valueString := strings.Repeat("a", valueSize)
+
+	payload := make(map[string]interface{}, numEntries)
+	for i := 0; i < numEntries; i++ {
+		key := fmt.Sprintf("key_%d", i)
+		payload[key] = valueString
+	}
+	resp := testHttpPut(t, token, addr+"/v1/secret/foo", payload)
+
 	testResponseStatus(t, resp, http.StatusRequestEntityTooLarge)
 }
 
@@ -1071,9 +1084,11 @@ func TestLogical_SnapshotParams(t *testing.T) {
 		method                 string
 		url                    string
 		body                   []byte
+		headers                map[string]string
 		wantData               map[string]interface{}
 		wantOperation          logical.Operation
 		wantRequiresSnapshotID string
+		wantError              bool
 	}{
 		{
 			name:                   "normal get",
@@ -1109,6 +1124,31 @@ func TestLogical_SnapshotParams(t *testing.T) {
 			wantOperation:          logical.ReadOperation,
 			wantRequiresSnapshotID: "1234",
 		},
+		{
+			name:   "snapshot list header",
+			method: http.MethodGet,
+			url:    "https://example.com?list=true",
+			body:   nil,
+			headers: map[string]string{
+				VaultSnapshotRecoverHeader: "1234",
+			},
+			wantData:               nil,
+			wantOperation:          logical.ListOperation,
+			wantRequiresSnapshotID: "",
+		},
+		{
+			name:   "snapshot read header",
+			method: http.MethodGet,
+			url:    "https://example.com",
+			headers: map[string]string{
+				VaultSnapshotRecoverHeader: "1234",
+			},
+			body:                   nil,
+			wantData:               nil,
+			wantOperation:          logical.ReadOperation,
+			wantRequiresSnapshotID: "",
+		},
+
 		{
 			name:   "normal update",
 			method: http.MethodPost,
@@ -1130,6 +1170,44 @@ func TestLogical_SnapshotParams(t *testing.T) {
 			wantOperation:          logical.RecoverOperation,
 			wantRequiresSnapshotID: "1234",
 		},
+		{
+			name:   "snapshot update header",
+			method: http.MethodPost,
+			url:    "https://example.com",
+			body:   []byte(`{"other_data":"abcd"}`),
+			headers: map[string]string{
+				VaultSnapshotRecoverHeader: "1234",
+			},
+			wantData: map[string]interface{}{
+				"other_data": "abcd",
+			},
+			wantOperation:          logical.RecoverOperation,
+			wantRequiresSnapshotID: "1234",
+		},
+		{
+			name:   "recover operation no snapshot",
+			method: "RECOVER",
+			url:    "https://example.com",
+			body:   []byte(`{"other_data":"abcd"}`),
+			headers: map[string]string{
+				"other_header": "value",
+			},
+			wantError: true,
+		},
+		{
+			name:   "recover operation with snapshot",
+			method: "RECOVER",
+			url:    "https://example.com",
+			body:   []byte(`{"other_data":"abcd"}`),
+			headers: map[string]string{
+				VaultSnapshotRecoverHeader: "1234",
+			},
+			wantOperation: logical.RecoverOperation,
+			wantData: map[string]interface{}{
+				"other_data": "abcd",
+			},
+			wantRequiresSnapshotID: "1234",
+		},
 	}
 
 	for _, tc := range testCases {
@@ -1137,8 +1215,14 @@ func TestLogical_SnapshotParams(t *testing.T) {
 			req, _ := http.NewRequest(tc.method, tc.url, bytes.NewReader(tc.body))
 			req = req.WithContext(namespace.RootContext(nil))
 			req.Header.Add(consts.AuthHeaderName, rootToken)
-
+			for k, v := range tc.headers {
+				req.Header.Add(k, v)
+			}
 			lreq, _, status, err := buildLogicalRequest(core, nil, req, "")
+			if tc.wantError {
+				require.Error(t, err)
+				return
+			}
 			require.NoError(t, err)
 			require.Equal(t, 0, status)
 			require.Equal(t, tc.wantOperation, lreq.Operation)
