@@ -1,5 +1,5 @@
 /**
- * Copyright (c) HashiCorp, Inc.
+ * Copyright IBM Corp. 2016, 2025
  * SPDX-License-Identifier: BUSL-1.1
  */
 
@@ -7,5 +7,6 @@ import kubernetes from './kubernetes';
 import ldap from './ldap';
 import sync from './sync';
 import customLogin from './custom-login';
+import recovery from './recovery';
 
-export { kubernetes, ldap, sync, customLogin };
+export { kubernetes, ldap, sync, customLogin, recovery };
