@@ -1,19 +1,10 @@
 /**
- * Copyright (c) HashiCorp, Inc.
+ * Copyright IBM Corp. 2016, 2025
  * SPDX-License-Identifier: BUSL-1.1
  */
 
 import { module, test } from 'qunit';
-import {
-  visit,
-  currentURL,
-  settled,
-  fillIn,
-  click,
-  waitUntil,
-  find,
-  currentRouteName,
-} from '@ember/test-helpers';
+import { visit, currentURL, settled, fillIn, click, waitFor, currentRouteName } from '@ember/test-helpers';
 import { setupApplicationTest } from 'vault/tests/helpers';
 import { setupMirage } from 'ember-cli-mirage/test-support';
 import { selectChoose } from 'ember-power-select/test-support';
@@ -26,7 +17,7 @@ import { pollCluster } from 'vault/tests/helpers/poll-cluster';
 import { disableReplication } from 'vault/tests/helpers/replication';
 import connectionPage from 'vault/tests/pages/secrets/backend/database/connection';
 import { v4 as uuidv4 } from 'uuid';
-import { runCmd, deleteEngineCmd, createNS } from 'vault/tests/helpers/commands';
+import { runCmd, deleteEngineCmd, createNS, deleteNS } from 'vault/tests/helpers/commands';
 
 import { DASHBOARD } from 'vault/tests/helpers/components/dashboard/dashboard-selectors';
 import { CUSTOM_MESSAGES } from 'vault/tests/helpers/config-ui/message-selectors';
@@ -227,6 +218,11 @@ module('Acceptance | landing page dashboard', function (hooks) {
       await runCmd(createNS('world'), false);
       await visit('/vault/dashboard?namespace=world');
       assert.dom(DASHBOARD.cardName('configuration-details')).doesNotExist();
+
+      // navigate to "root" before deleting
+      await visit('vault/dashboard');
+      // clean up namespace pollution
+      await runCmd(deleteNS('world'));
     });
 
     test('shows the configuration details card', async function (assert) {
@@ -345,7 +341,7 @@ module('Acceptance | landing page dashboard', function (hooks) {
       await connectionPage.name(name);
       await connectionPage.connectionUrl(`mongodb://127.0.0.1:4321/${name}`);
       await connectionPage.toggleVerify();
-      await click(GENERAL.saveButton);
+      await click(GENERAL.submitButton);
       await connectionPage.enable();
       return name;
     };
@@ -396,6 +392,7 @@ module('Acceptance | landing page dashboard', function (hooks) {
       this.store = this.owner.lookup('service:store');
 
       await login();
+      this.response = await this.store.findRecord('clients/activity', 'clients/activity');
     });
 
     test('shows the client count card for enterprise', async function (assert) {
@@ -403,17 +400,19 @@ module('Acceptance | landing page dashboard', function (hooks) {
       assert.true(version.isEnterprise, 'version is enterprise');
       assert.strictEqual(currentURL(), '/vault/dashboard');
       assert.dom(DASHBOARD.cardName('client-count')).exists();
-      const response = await this.store.peekRecord('clients/activity', 'clients/activity');
       assert.dom('[data-test-client-count-title]').hasText('Client count');
+      await waitFor('[data-test-stat-text="Total"] .stat-label');
       assert.dom('[data-test-stat-text="Total"] .stat-label').hasText('Total');
-      assert.dom('[data-test-stat-text="Total"] .stat-value').hasText(formatNumber([response.total.clients]));
+      assert
+        .dom('[data-test-stat-text="Total"] .stat-value')
+        .hasText(formatNumber([this.response.total.clients]));
       assert.dom('[data-test-stat-text="New"] .stat-label').hasText('New');
       assert
         .dom('[data-test-stat-text="New"] .stat-text')
         .hasText('The number of clients new to Vault in the current month.');
       assert
         .dom('[data-test-stat-text="New"] .stat-value')
-        .hasText(formatNumber([response.byMonth.lastObject.new_clients.clients]));
+        .hasText(formatNumber([this.response.byMonth.lastObject.new_clients.clients]));
       assert
         .dom(`${GENERAL.flashMessage}.is-info`)
         .doesNotExist('Does not show warning about client count estimations');
@@ -450,6 +449,11 @@ module('Acceptance | landing page dashboard', function (hooks) {
       await runCmd(createNS('blah'), false);
       await visit('/vault/dashboard?namespace=blah');
       assert.dom(DASHBOARD.cardName('replication')).doesNotExist();
+
+      // navigate to "root" before deleting
+      await visit('vault/dashboard');
+      // clean up namespace pollution
+      await runCmd(deleteNS('blah'));
     });
 
     test('it should show replication status if both dr and performance replication are enabled as features in enterprise', async function (assert) {
@@ -459,12 +463,9 @@ module('Acceptance | landing page dashboard', function (hooks) {
       assert.strictEqual(currentURL(), '/vault/replication');
       await click('[data-test-replication-type-select="performance"]');
       await fillIn('[data-test-replication-cluster-mode-select]', 'primary');
-      await click(GENERAL.saveButton);
+      await click(GENERAL.submitButton);
       await pollCluster(this.owner);
-      assert.ok(
-        await waitUntil(() => find('[data-test-replication-dashboard]')),
-        'details dashboard is shown'
-      );
+      await waitFor('[data-test-replication-dashboard]');
       await visit('/vault/dashboard');
       assert.dom(DASHBOARD.title('DR primary')).hasText('DR primary');
       assert.dom(DASHBOARD.tooltipTitle('DR primary')).hasText('not set up');
@@ -491,11 +492,11 @@ module('Acceptance | landing page dashboard', function (hooks) {
       assert.dom(CUSTOM_MESSAGES.modalTitle(modalId)).hasText('Modal title');
       assert.dom(CUSTOM_MESSAGES.modalBody(modalId)).exists();
       assert.dom(CUSTOM_MESSAGES.modalBody(modalId)).hasText('here is a cool message');
-      await click(CUSTOM_MESSAGES.modalButton(modalId));
       assert.dom(CUSTOM_MESSAGES.alertTitle(alertId)).hasText('Banner title');
       assert.dom(CUSTOM_MESSAGES.alertDescription(alertId)).hasText('hello world hello wolrd');
       assert.dom(CUSTOM_MESSAGES.alertAction('link')).hasText('some link title');
     });
+
     test('it shows the multiple modal messages', async function (assert) {
       const modalIdOne = 'some-awesome-id-2';
       const modalIdTwo = 'some-awesome-id-1';
@@ -512,13 +513,12 @@ module('Acceptance | landing page dashboard', function (hooks) {
       assert.dom(CUSTOM_MESSAGES.modalTitle(modalIdOne)).hasText('Modal title 1');
       assert.dom(CUSTOM_MESSAGES.modalBody(modalIdOne)).exists();
       assert.dom(CUSTOM_MESSAGES.modalBody(modalIdOne)).hasText('hello world hello wolrd some link title');
-      await click(CUSTOM_MESSAGES.modalButton(modalIdOne));
       assert.dom(CUSTOM_MESSAGES.modal(modalIdTwo)).exists();
       assert.dom(CUSTOM_MESSAGES.modalTitle(modalIdTwo)).hasText('Modal title 2');
       assert.dom(CUSTOM_MESSAGES.modalBody(modalIdTwo)).exists();
       assert.dom(CUSTOM_MESSAGES.modalBody(modalIdTwo)).hasText('here is a cool message');
-      await click(CUSTOM_MESSAGES.modalButton(modalIdTwo));
     });
+
     test('it shows the multiple banner messages', async function (assert) {
       const bannerIdOne = 'some-awesome-id-2';
       const bannerIdTwo = 'some-awesome-id-1';
