@@ -1,5 +1,5 @@
 /**
- * Copyright (c) HashiCorp, Inc.
+ * Copyright IBM Corp. 2016, 2025
  * SPDX-License-Identifier: BUSL-1.1
  */
 /* eslint-disable no-useless-escape */
@@ -23,6 +23,7 @@ import {
   mountEngineCmd,
   runCmd,
   createTokenCmd,
+  deleteNS,
 } from 'vault/tests/helpers/commands';
 import {
   dataPolicy,
@@ -31,14 +32,15 @@ import {
   metadataListPolicy,
   metadataPolicy,
 } from 'vault/tests/helpers/kv/policy-generator';
-import { clearRecords, writeSecret, writeVersionedSecret } from 'vault/tests/helpers/kv/kv-run-commands';
+import { writeSecret, writeVersionedSecret } from 'vault/tests/helpers/kv/kv-run-commands';
 import { FORM, PAGE } from 'vault/tests/helpers/kv/kv-selectors';
 import { GENERAL } from 'vault/tests/helpers/general-selectors';
-import { SECRET_ENGINE_SELECTORS as SES } from 'vault/tests/helpers/secret-engine/secret-engine-selectors';
 import codemirror, { getCodeEditorValue, setCodeEditorValue } from 'vault/tests/helpers/codemirror';
 import { personas } from 'vault/tests/helpers/kv/policy-generator';
 import { capabilitiesStub } from 'vault/tests/helpers/stubs';
 import { setupMirage } from 'ember-cli-mirage/test-support';
+import { selectChoose } from 'ember-power-select/test-support';
+import { DASHBOARD } from 'vault/tests/helpers/components/dashboard/dashboard-selectors';
 
 /**
  * This test set is for testing edge cases, such as specific bug fixes or reported user workflows
@@ -50,8 +52,8 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
   hooks.beforeEach(async function () {
     const uid = uuidv4();
     this.backend = `kv-edge-${uid}`;
-    this.rootSecret = 'root_directory';
-    this.fullSecretPath = `${this.rootSecret}/nested/child_secret`;
+    this.rootSecret = 'root-directory';
+    this.fullSecretPath = `${this.rootSecret}/nested/child-secret`;
     await login();
     await runCmd(mountEngineCmd('kv-v2', this.backend), false);
     await writeSecret(this.backend, this.fullSecretPath, 'foo', 'bar');
@@ -66,7 +68,7 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
     return;
   });
 
-  module('persona with read and list access on the secret level', function (hooks) {
+  module('persona with glob (*) read and list access on the secret level', function (hooks) {
     // see github issue for more details https://github.com/hashicorp/vault/issues/5362
     hooks.beforeEach(async function () {
       const secretPath = `${this.rootSecret}/*`; // user has LIST and READ access within this root secret directory
@@ -93,14 +95,14 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
 
       await typeIn(PAGE.list.overviewInput, `${root}/no-access/`);
       assert
-        .dom(PAGE.list.overviewButton)
+        .dom(GENERAL.submitButton)
         .hasText('View list', 'shows list and not secret because search is a directory');
-      await click(PAGE.list.overviewButton);
+      await click(GENERAL.submitButton);
       assert.dom(GENERAL.emptyStateTitle).hasText(`There are no secrets matching "${root}/no-access/".`);
 
       await visit(`/vault/secrets/${backend}/kv/list`);
       await typeIn(PAGE.list.overviewInput, `${root}/`); // add slash because this is a directory
-      await click(PAGE.list.overviewButton);
+      await click(GENERAL.submitButton);
 
       // URL correct
       assert.strictEqual(
@@ -120,10 +122,10 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
       assert.dom(PAGE.toolbarAction).exists({ count: 1 }, 'toolbar only renders create secret action');
       assert.dom(PAGE.list.filter).hasValue(`${root}/`);
       // List content correct
-      assert.dom(PAGE.list.item(`${subdirectory}/`)).exists('renders linked block for subdirectory');
-      await click(PAGE.list.item(`${subdirectory}/`));
-      assert.dom(PAGE.list.item(secret)).exists('renders linked block for child secret');
-      await click(PAGE.list.item(secret));
+      assert.dom(GENERAL.listItem(`${subdirectory}/`)).exists('renders linked block for subdirectory');
+      await click(GENERAL.listItem(`${subdirectory}/`));
+      assert.dom(GENERAL.listItem(secret)).exists('renders linked block for child secret');
+      await click(GENERAL.listItem(secret));
       assert
         .dom(GENERAL.overviewCard.container('Current version'))
         .hasText(`Current version The current version of this secret. 1`);
@@ -155,7 +157,7 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
         'goes back to subdirectory list'
       );
       assert.dom(PAGE.list.filter).hasValue(`${root}/${subdirectory}/`);
-      assert.dom(PAGE.list.item(secret)).exists('renders linked block for child secret');
+      assert.dom(GENERAL.listItem(secret)).exists('renders linked block for child secret');
 
       // back again
       previousCrumb = findAll(GENERAL.breadcrumb).length - 2;
@@ -165,7 +167,7 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
         `/vault/secrets/${backend}/kv/list/${root}/`,
         'goes back to root directory'
       );
-      assert.dom(PAGE.list.item(`${subdirectory}/`)).exists('renders linked block for subdirectory');
+      assert.dom(GENERAL.listItem(`${subdirectory}/`)).exists('renders linked block for subdirectory');
 
       // and back to the engine list view
       previousCrumb = findAll(GENERAL.breadcrumb).length - 2;
@@ -181,11 +183,11 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
       assert.expect(7);
       const backend = this.backend;
       const [root, subdirectory] = this.fullSecretPath.split('/');
-      setupOnerror((error) => assert.strictEqual(error.httpStatus, 404), '404 error is thrown'); // catches error so qunit test doesn't fail
+      setupOnerror((error) => assert.strictEqual(error.response.status, 404), '404 error is thrown'); // catches error so qunit test doesn't fail
 
       await visit(`/vault/secrets/${backend}/kv/list`);
       await typeIn(PAGE.list.overviewInput, `${root}/${subdirectory}`); // intentionally leave out trailing slash
-      await click(PAGE.list.overviewButton);
+      await click(GENERAL.submitButton);
       assert.dom(PAGE.error.title).hasText('404 Not Found');
       assert
         .dom(PAGE.error.message)
@@ -212,7 +214,7 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
 
       await visit(`/vault/secrets/${this.backend}/kv/list`);
       await typeIn(PAGE.list.overviewInput, 'my_secret');
-      await click(PAGE.list.overviewButton);
+      await click(GENERAL.submitButton);
       assert.strictEqual(
         currentURL(),
         `/vault/secrets/${this.backend}/kv/my_secret`,
@@ -222,6 +224,57 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
     });
   });
 
+  module('persona with list access on a secret path', function (hooks) {
+    // test coverage for this regression: https://github.com/hashicorp/vault/issues/31606
+    hooks.beforeEach(async function () {
+      const secretPath = this.rootSecret;
+      const capabilities = ['list'];
+      const backend = this.backend;
+      const token = await runCmd([
+        createPolicyCmd(
+          `secret-lister-${this.backend}`,
+          metadataPolicy({ backend, secretPath, capabilities })
+        ),
+        createTokenCmd(`secret-lister-${this.backend}`),
+      ]);
+      await login(token);
+    });
+
+    test('it lists secrets within the root directory from the kv engine list', async function (assert) {
+      assert.expect(4);
+      const backend = this.backend;
+      const [root, subdirectory] = this.fullSecretPath.split('/');
+
+      await visit(`/vault/secrets/${backend}/kv/list`);
+      assert.strictEqual(currentURL(), `/vault/secrets/${backend}/kv/list`, 'lands on secrets list page');
+      await typeIn(PAGE.list.overviewInput, `${root}/`);
+      await click(GENERAL.submitButton);
+      assert.strictEqual(
+        currentURL(),
+        `/vault/secrets/${backend}/kv/list/${root}/`,
+        'it navigates to secret list'
+      );
+      assert.dom(PAGE.list.filter).hasValue(`${root}/`);
+      assert.dom(PAGE.list.item(`${subdirectory}/`)).exists('it renders nested secret');
+    });
+
+    test('it lists secrets within the root directory from the quick actions card', async function (assert) {
+      assert.expect(2);
+      const backend = this.backend;
+      const [root, subdirectory] = this.fullSecretPath.split('/');
+
+      await visit(`/vault`);
+      await selectChoose(DASHBOARD.searchSelect('secrets-engines'), backend);
+      await fillIn(DASHBOARD.selectEl, 'Find KV secrets');
+      await typeIn(GENERAL.kvSuggestion.input, `${root}/`);
+      await click(GENERAL.kvSuggestion.input);
+      assert
+        .dom(GENERAL.searchSelect.options)
+        .hasText(`${subdirectory}/`)
+        .exists({ count: 1 }, 'expected options render');
+    });
+  });
+
   module('destruction without read', function (hooks) {
     hooks.beforeEach(async function () {
       const backend = this.backend;
@@ -305,7 +358,7 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
   test('no ghost item after editing metadata', async function (assert) {
     await visit(`/vault/secrets/${this.backend}/kv/list/edge/`);
     assert.dom(PAGE.list.item()).exists({ count: 2 }, 'two secrets are listed');
-    await click(PAGE.list.item('two'));
+    await click(GENERAL.listItem('two'));
     await click(PAGE.secretTab('Metadata'));
     await click(PAGE.metadata.editBtn);
     await fillIn(FORM.keyInput(), 'foo');
@@ -319,7 +372,7 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
     await visit(`/vault/secrets/${this.backend}/kv/create`);
     await fillIn(FORM.inputByAttr('path'), 'complex');
 
-    await click(FORM.toggleJson);
+    await click(GENERAL.toggleInput('json'));
 
     await waitFor('.cm-editor');
     const view = codemirror();
@@ -336,8 +389,8 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
 
     // Details view
     await click(PAGE.secretTab('Secret'));
-    assert.dom(FORM.toggleJson).isNotDisabled('JSON toggle is not disabled');
-    assert.dom(FORM.toggleJson).isChecked("JSON toggle is checked 'on'");
+    assert.dom(GENERAL.toggleInput('json')).isNotDisabled('JSON toggle is not disabled');
+    assert.dom(GENERAL.toggleInput('json')).isChecked("JSON toggle is checked 'on'");
 
     assert
       .dom(GENERAL.codeBlock('secret-data'))
@@ -345,8 +398,8 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
 
     // New version view
     await click(PAGE.detail.createNewVersion);
-    assert.dom(FORM.toggleJson).isNotDisabled();
-    assert.dom(FORM.toggleJson).isChecked();
+    assert.dom(GENERAL.toggleInput('json')).isNotDisabled();
+    assert.dom(GENERAL.toggleInput('json')).isChecked();
     assert.deepEqual(
       getCodeEditorValue(view),
       '{ "foo3": { "name": "bar3" } }',
@@ -409,8 +462,8 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
     await fillIn(FORM.maskedValueInput(), '{bar}');
     await click(FORM.saveBtn);
     await click(GENERAL.overviewCard.actionText('Create new'));
-    assert.dom(FORM.toggleJson).isNotDisabled();
-    assert.dom(FORM.toggleJson).isNotChecked();
+    assert.dom(GENERAL.toggleInput('json')).isNotDisabled();
+    assert.dom(GENERAL.toggleInput('json')).isNotChecked();
   });
 
   // patch is technically enterprise only but stubbing the version so these tests run on both CE and enterprise
@@ -428,9 +481,7 @@ module('Acceptance | kv-v2 workflow | edge cases', function (hooks) {
         ),
         createTokenCmd(`secret-patcher-${this.backend}`),
       ]);
-      await login(token);
-      clearRecords(this.store);
-      return;
+      return login(token);
     });
 
     test('it patches a secret from the overview page', async function (assert) {
@@ -512,7 +563,7 @@ module('Acceptance | Enterprise | kv-v2 workflow | edge cases', function (hooks)
 
   const navToEngine = async (backend) => {
     await click(GENERAL.navLink('Secrets Engines'));
-    return await click(SES.secretsBackendLink(backend));
+    return await click(`${GENERAL.tableData(`${backend}/`, 'path')} a`);
   };
 
   const assertDeleteActions = (assert, expected = ['delete', 'destroy']) => {
@@ -550,7 +601,7 @@ module('Acceptance | Enterprise | kv-v2 workflow | edge cases', function (hooks)
 
   hooks.afterEach(async function () {
     await login();
-    await runCmd([`delete /sys/auth/${this.namespace}`]);
+    await runCmd(deleteNS(this.namespace));
     await runCmd(deleteEngineCmd(this.backend));
     return;
   });
@@ -559,9 +610,7 @@ module('Acceptance | Enterprise | kv-v2 workflow | edge cases', function (hooks)
     hooks.beforeEach(async function () {
       await loginNs(this.namespace);
       // mount engine within namespace
-      await runCmd(mountEngineCmd('kv-v2', this.backend), false);
-      clearRecords(this.store);
-      return;
+      return runCmd(mountEngineCmd('kv-v2', this.backend), false);
     });
     hooks.afterEach(async function () {
       // visit logout with namespace query param because we're transitioning from within an engine
