@@ -1,5 +1,5 @@
 /**
- * Copyright (c) HashiCorp, Inc.
+ * Copyright IBM Corp. 2016, 2025
  * SPDX-License-Identifier: BUSL-1.1
  */
 
@@ -25,7 +25,6 @@ const SELECTORS = {
   versionRow: (version) => `[data-test-transit-version="${version}"]`,
   rotate: {
     trigger: '[data-test-transit-key-rotate]',
-    confirm: '[data-test-confirm-button]',
   },
 };
 
@@ -164,7 +163,7 @@ const testConvergentEncryption = async function (assert, keyName) {
       await click('[data-test-transit-b64-toggle="context"]');
     }
     assert.dom('[data-test-encrypt-modal]').doesNotExist(`${keyName}: is not open before encrypt`);
-    await click('[data-test-button-encrypt]');
+    await click(GENERAL.submitButton);
 
     if (testCase.assertAfterEncrypt) {
       await settled();
@@ -184,7 +183,7 @@ const testConvergentEncryption = async function (assert, keyName) {
 
     setCodeEditorValue(editor, copiedCiphertext);
 
-    await click('[data-test-button-decrypt]');
+    await click(GENERAL.submitButton);
 
     if (testCase.assertAfterDecrypt) {
       await settled();
@@ -355,7 +354,7 @@ module('Acceptance | transit', function (hooks) {
     assert.dom(SELECTORS.versionRow(1)).hasTextContaining('Version 1', `${name}: only one key version`);
 
     await click(SELECTORS.rotate.trigger);
-    await click(SELECTORS.rotate.confirm);
+    await click(GENERAL.confirmButton);
 
     assert.dom(SELECTORS.versionRow(2)).exists('two key versions after rotate');
 
@@ -476,7 +475,7 @@ module('Acceptance | transit', function (hooks) {
       assert.dom('[data-test-transit-version]').exists({ count: 1 }, `${name}: only one key version`);
       await click(SELECTORS.rotate.trigger);
 
-      await click(SELECTORS.rotate.confirm);
+      await click(GENERAL.confirmButton);
       assert
         .dom('[data-test-transit-version]')
         .exists({ count: 2 }, `${name}: two key versions after rotate`);
