@@ -1,5 +1,5 @@
 /**
- * Copyright (c) HashiCorp, Inc.
+ * Copyright IBM Corp. 2016, 2025
  * SPDX-License-Identifier: BUSL-1.1
  */
 
@@ -31,8 +31,6 @@ export default create({
   menuItems: collection('.ember-basic-dropdown-content li', {
     testContainer: '#ember-testing',
   }),
-  delete: clickable('[data-test-confirm-action-trigger]'),
-  confirmDelete: clickable('[data-test-confirm-button]'),
   backendIsEmpty: getter(function () {
     return this.secrets.length === 0;
   }),
